Upload picture byte size and op count metrics for SKP recording.

Look okay?

{
   "results" : {
      "desk_amazon.skp_1264_3999" : {
         "nonrendering" : {
            "bytes" : 75656,
            "max_ms" : 1.150187,
            "mean_ms" : 1.150187,
            "median_ms" : 1.150187,
            "min_ms" : 1.150187,
            "ops" : 659,
            "options" : {
               "bench_type" : "recording",
               "clip" : "0 0 1000 1000",
               "name" : "desk_amazon.skp",
               "scale" : "1",
               "source_type" : "skp"
            }
         }
      },
...

BUG=skia:

Review URL: https://codereview.chromium.org/773323002
diff --git a/bench/ResultsWriter.h b/bench/ResultsWriter.h
index b8d9707..f53a980 100644
--- a/bench/ResultsWriter.h
+++ b/bench/ResultsWriter.h
@@ -34,7 +34,7 @@
     virtual void property(const char name[], const char value[]) {}
 
     // Denote the start of a specific benchmark. Once bench is called,
     // then config and timer can be called multiple times to record runs.
     virtual void bench(const char name[], int32_t x, int32_t y) {}
 
     // Record the specific configuration a bench is run under, such as "8888".
@@ -44,7 +44,7 @@
     virtual void configOption(const char name[], const char* value) {}
 
     // Record a single test metric.
-    virtual void timer(const char name[], double ms) {}
+    virtual void metric(const char name[], double ms) {}
 
     // Flush to storage now please.
     virtual void flush() {}
@@ -105,7 +105,7 @@
     virtual void configOption(const char name[], const char* value) {
         (*fConfig)["options"][name] = value;
     }
-    virtual void timer(const char name[], double ms) {
+    virtual void metric(const char name[], double ms) {
         // Don't record if nan, or -nan.
         if (sk_double_isnan(ms)) {
             return;
@@ -34,7 +34,7 @@
 
     // Denote the start of a specific benchmark. Once bench is called,
-    // then config and timer can be called multiple times to record runs.
+    // then config and metric can be called multiple times to record runs.
     virtual void bench(const char name[], int32_t x, int32_t y) {}
 